Method: Cod::Channel#get

Defined in:
lib/cod/channel.rb

#getObject

Obtains one message from the channel. If the channel is empty, but theoretically able to receive more messages, blocks forever. But if the channel is somehow broken, an exception is raised.

Returns:

  • (Object)

    the next message waiting in the channel



28
29
30
# File 'lib/cod/channel.rb', line 28

def get
  abstract_method_error
end